## 0.0.59

This new version includes a critical bug fix related to the creation of the ZOTERO_JSON_DIR directory.

### New Features

No new features were added in this version.

### Bug Fixes

- Fixed the method of directory creation for ZOTERO_JSON_DIR to ensure correct creation (a6a0c7) (Eric Ma)

### Deprecations

No deprecations were made in this version.
